////////////////////////////////////////////////////////

var video_mode = 7; // 800x600
var video_depth = 16; // 16 bit mode

var lives = 5; // number of lives
var points = 0; // number of points at game start
var speed = 4; // movement speed
var animation_speed = 7; // animation speed
var step_width = 64; // distance between 2 steps on x and y
var falling = 0; // will be set to 1 if the player is falling

//////////////////////////////////////////////////////////////

font skinc_font = <font.pcx>, 24, 23; // sword combat font

//////////////////////////////////////////////////////////////

sound beep_sound = <beep.wav>;
sound break_sound = <break.wav>;
sound falling_sound = <falling.wav>;
sound bonus_sound = <bonus.wav>;
sound finished_sound = <finished.wav>;

//////////////////////////////////////////////////////////////

function check_content();

//////////////////////////////////////////////////////////////

string skinc_wmb = <skinc.wmb>;

string skinc_str = " Lives:              Points:"; 

///////////////////////////////////////////////////////////////

panel skinc_pan // displays the numbers
{
	pos_x = 0;
	pos_y = 0;
	digits = 120, 575, 4, skinc_font, 1, lives;
	digits = 650, 575, 4, skinc_font, 1, points;
	flags = refresh, visible;
}

text skinc_txt // displays "Lives:" and "Points:"
{
	pos_x = 0;
	pos_y = 575;
	font = skinc_font;	
	string = skinc_str;
	flags = visible;
}

////////////////////////////////////////////////////////////////

function main()
{
	level_load (skinc_wmb);
	wait (2); // wait for the level to be loaded
	clip_size = 0; // show all the triangles for all the models
	fps_max = 30; // lock the frame rate to 30 fps
}	

action init_camera
{
	my.invisible = on;
	while (player == null) {wait (1);}
	vec_set (camera.pos, my.pos);
	while (1)
	{
		camera.arc = max (10, (camera.arc - 2 * time * key_pgup)); // press "+" and "-"
		camera.arc = min (70, (camera.arc + 2 * time * key_pgdn)); // to zoom in  / out
		vec_set (temp.x, player.x);
		vec_sub (temp.x, my.x);
		vec_to_angle (camera.pan, temp); // rotate towards the player
		wait (1);
	}
}

action skeleton // the player
{
	while (key_any == 1) {wait (1);} // wait until all the keys are released (useful at restart)
	my.z = 30; // place it at the floor level, play with this value
	player = me; // I'm the player
	falling = 0; // and I'm not falling right now
	while (lives > 0) // as long as I'm alive
	{
		if (key_cuu == 1) // if we press the "up" arrow
		{
			my.pan = 0;	// rotate in that direction
			my.skill10 = my.x; // store the current x position in skill10
			while ((my.x < my.skill10 + step_width) && (falling == 0)) // as long as I haven't walked step_width
			{
				ent_cycle("walk", my.skill20); // play walk frames animation
				my.skill20 += animation_speed * time; // "walk" animation speed
				my.skill20 %= 100; // loop the animation 				
				my.x += speed * time; // move the player without ent_move
				check_content(); // see if the player is on solid ground
				wait (1);
			}
		}
		if (key_cud == 1) 
		{
			my.pan = 180;	
			my.skill10 = my.x;
			while ((my.x > my.skill10 - step_width) && (falling == 0))
			{
				ent_cycle("walk", my.skill20); // play walk frames animation
				my.skill20 -= animation_speed * time; // reversed "walk" animation
				my.skill20 %= 100; // loop the animation 				
				my.x -= speed * time;
				check_content();
				wait (1);
			}
		}
		if (key_cul == 1) 
		{
			my.pan = 90;
			my.skill10 = my.y;
			while ((my.y < my.skill10 + step_width) && (falling == 0))
			{
				ent_cycle("walk", my.skill20); // play walk frames animation
				my.skill20 += animation_speed * time; // "walk" animation speed
				my.skill20 %= 100; // loop the animation 				
				my.y += speed * time;
				check_content();
				wait (1);
			}
		}
		if (key_cur == 1) 
		{
			my.pan = 270;	
			my.skill10 = my.y;
			while ((my.y > my.skill10 - step_width) && (falling == 0))
			{
				ent_cycle("walk", my.skill20); // play walk frames animation
				my.skill20 += animation_speed * time; // "walk" animation speed
				my.skill20 %= 100; // loop the animation 				
				my.y -= speed * time;
				check_content();
				wait (1);
			}
		}
		wait (1);
	}
	my.skill20 = 0;
	while (my.skill20 < 100) // the player is dead
	{
		ent_cycle("death", my.skill20); // play death frames animation
		my.skill23 += 5 * time; // "death" animation speed
		wait (1);
	}
}

function check_content()
{
	vec_set (temp, my.pos); // copy player's coordinates in temp
	temp.z -= 64; // and check the content of the floor
	if (content (temp) != content_solid) // if it is a hole, the player will fall
	{
		exclusive_global; // stop all the other instances of this action
		lives -= 1; // decrease the number of lives
		falling = 1; // the player is falling, needed in action skeleton
		snd_play (falling_sound, 70, 0); 
		while (player.z > -1000) // as long as it hasn't reached the bottom
		{
			player.z -= 35 * time; // make it fall
			wait (1);
		}
		sleep (2); // wait for 2 seconds
		if (lives > 0)
		{
			points = 0; // reset the score
			main(); // restart the level
		}
	}
	else
	{
		falling = 0; // walking on solid ground
	}
}

action block_breakable
{
	while (player == null) {wait (1);}
	while (vec_dist (player.x, my.x) > 70) {wait (1);}
	sleep (1.5); // wait 1.5 seconds
	ent_morph (my, "block2.wmb"); // morph the initial block into this one
	snd_play (break_sound, 50, 0);
	sleep (0.1);	
	ent_morph (my, "block3.wmb"); // then this block
	sleep (0.1);	
	ent_morph (my, "block4.wmb"); // and finally this block
	sleep (0.1);
	while (my.z > -500) // now move the final block downwards
	{
		my.z -= 15 * time;
		wait (1);
	}
	ent_remove (me); // and then remove it
}

action bonus1
{
	while (player == null) {wait (1);}
	my.passable = on;
	my.transparent = on;
	my.light = on;
	my.bright = on;
	my.lightgreen = 250;
	my.lightrange = 0;
	while (vec_dist (player.x, my.x) > 30) 
	{
		my.pan += 3 * time; // rotate if the player is far
		wait (1);
	}
	snd_play (bonus_sound, 30, 0);
	while (my.scale_x < 3)
	{
		my.scale_x += 0.1 * time; // increase my scale
		my.scale_y = my.scale_x; // on x, y, and z
		my.scale_z = my.scale_x;
		my.z += 0.5 * time; // and increase my height
		my.alpha -= 2 * time; // decrease my alpha transparency
		wait (1);
	}
	points += 10; // add 10 points to the score
	ent_remove (me); // and then remove me
}

action block_end
{
	my.invisible = on;
	my.passable = on;
	while (points < 100) {wait (1);} // will be invisible until the player has 100 points
	my.passable = off;
	my.invisible = off;
	snd_play (finished_sound, 30, 0);	
	sleep (0.5);
	my.invisible = on;
	snd_play (finished_sound, 30, 0);	
	sleep (0.5);
	my.invisible = off;
	snd_play (finished_sound, 30, 0);	
}		
	
action flag
{
	my.passable = on;
	while (player == null) {wait (1);}
	while (vec_dist (my.x, player.x) > 50) {wait (1);}
	player.light = on;
	player.lightred = 250;
	player.lightrange = 100;
	sleep (3); // wait for 3 seconds
	exit; // shut down the engine
}